# nerdbridge

the nerdbridge package contains a minimal version of a bridge server and client which allows running a (local) bridge server from the command line and connecting 4 clients to it.
The clients get an asci style window which shows the hand and allows them to do the bidding and play the game.

There's also a scorecalc which can calculate the score for each hand after it has been played, but that has not yet been implemented.
